#
# client.py - routines for snake client programs
#
# Copyright 2006, 2007 Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Red Hat, Inc. 
#

import snake.tree
import xmlrpclib

# Minimum snake XMLRPC API version
minimum_version = 1

def connect(server_url):
    '''Connect to the given server url. Returns a ServerProxy object.'''
    return xmlrpclib.ServerProxy(server_url)

def check_server(server_url):
    '''Check the server given by the URL.'''
    try:
        server = xmlrpclib.ServerProxy(server_url)
        methods = server.system.listMethods()
    except:
        return False

    if 'snake.version' not in methods:
        return False
    if server.snake.version() < minimum_version:
        return False

    return True

def treedict(server,**args):
    '''Return a dict of trees (using tree.id as the keys) that match the args
    given. Args will be passed to the server tree.list method.'''
    td = [(t['id'],snake.tree.Tree(dict=t)) for t in server.tree.list(args)]
    return dict(td)
